@@ -5,10 +5,10 @@ use warnings;
 
 use Error::Pure qw(err);
 use Mo qw(build default is);
-use Mo::utils qw(check_array_object);
+use Mo::utils qw(check_array_object check_number);
 use Wikibase::Datatype::Utils qw(check_entity);
 
-our $VERSION = 0.18;
+our $VERSION = 0.19;
 
 has forms => (
 	default => [],
@@ -45,6 +45,10 @@ has ns => (
 	is => 'ro',
 );
 
+has page_id => (
+	is => 'ro',
+);
+
 has senses => (
 	default => [],
 	is => 'ro',
@@ -76,6 +80,9 @@ sub BUILD {
 	# Check language.
 	check_entity($self, 'language');
 
+	# Check page id.
+	check_number($self, 'page_id');
+
 	# Check senses.
 	check_array_object($self, 'senses', 'Wikibase::Datatype::Sense',
 		'Sense');
@@ -112,6 +119,7 @@ Wikibase::Datatype::Lexeme - Wikibase lexeme datatype.
  my $lexical_category = $obj->lexical_category;
  my $modified = $obj->modified;
  my $ns = $obj->ns;
+ my $page_id = $obj->page_id;
  my $senses_ar = $obj->senses;
  my $statements_ar = $obj->statements;
  my $title = $obj->title;
@@ -174,6 +182,11 @@ Parameter is optional.
 Namespace.
 Default value is 146.
 
+=item * C<page_id>
+
+Page id. Numeric value.
+Parameter is optional.
+
 =item * C<senses>
 
 Senses.
@@ -257,6 +270,14 @@ Get namespace.
 
 Returns number.
 
+=head2 C<page_id>
+
+ my $page_id = $obj->page_id;
+
+Get page id.
+
+Returns number.
+
 =head2 C<senses>
 
  my $senses_ar = $obj->senses;
@@ -502,6 +523,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.18
+0.19
 
 =cut
